@@ -34,7 +34,8 @@ import statistics
 def objective_with_prune(trial: Trial, fast_check=True, X=None,y=None,fn_params=None, list_kpi=[], n_jobs=None, metric=None, num_rounds=None,early_stop=None,log=None,random_state=42):
     folds = 5
     
-    
+    kf = StratifiedKFold(n_splits=folds, shuffle=True, random_state=random_state)
+    ''' 
     test_size = hcm.get_test_size(X,log)
     if test_size == 0.20:
         kf = StratifiedKFold(n_splits=folds, shuffle=True, random_state=random_state)
@@ -42,7 +43,7 @@ def objective_with_prune(trial: Trial, fast_check=True, X=None,y=None,fn_params=
     else:
         kf = StratifiedShuffleSplit(n_splits=folds, test_size=test_size, random_state=random_state)
         print("StratifiedShuffleSplit")
-    
+    '''
     X_train = X
     y_train = y    
     
@@ -88,6 +89,9 @@ def objective_with_prune(trial: Trial, fast_check=True, X=None,y=None,fn_params=
     list_TN_valid_opt = []
     list_FN_valid_opt = []
     
+    list_opt_threshold_train = []
+    list_opt_threshold_valid = []
+    
     with_bias = False
     
     for train_idx, valid_idx in kf.split(X_train, y_train):
@@ -110,13 +114,19 @@ def objective_with_prune(trial: Trial, fast_check=True, X=None,y=None,fn_params=
         list_train_recall.append(kpi["train/recall"])
         list_train_f1.append(kpi["train/f1"])
         list_train_average_precision.append(kpi["train/average_precision"])
-        list_train_roc_auc.append(kpi["train/roc_auc"])        
+        list_train_roc_auc.append(kpi["train/roc_auc"])  
+        
+        
+         
+        
         
         list_TP_train.append(kpi["train/TP"])    
         list_FP_train.append(kpi["train/FP"])  
         list_TN_train.append(kpi["train/TN"])  
         list_FN_train.append(kpi["train/FN"])  
         
+        list_opt_threshold_train.append(kpi["train/opt_threshold_train"]) 
+        
         list_TP_train_opt.append(kpi["train/TP_opt"])    
         list_FP_train_opt.append(kpi["train/FP_opt"])  
         list_TN_train_opt.append(kpi["train/TN_opt"])  
@@ -135,6 +145,8 @@ def objective_with_prune(trial: Trial, fast_check=True, X=None,y=None,fn_params=
         list_TN_valid.append(kpi["valid/TN"])  
         list_FN_valid.append(kpi["valid/FN"])  
         
+        list_opt_threshold_valid.append(kpi["valid/opt_threshold_valid"]) 
+        
         list_TP_valid_opt.append(kpi["valid/TP_opt"])    
         list_FP_valid_opt.append(kpi["valid/FP_opt"])  
         list_TN_valid_opt.append(kpi["valid/TN_opt"])  
@@ -149,6 +161,14 @@ def objective_with_prune(trial: Trial, fast_check=True, X=None,y=None,fn_params=
         if fast_check:
             break
         
+    
+    mean_train_opt_threshold = statistics.mean(list_opt_threshold_train)
+    std_train_opt_threshold = statistics.pstdev(list_opt_threshold_train)
+    
+    mean_valid_opt_threshold = statistics.mean(list_opt_threshold_valid)
+    std_valid_opt_threshold = statistics.pstdev(list_opt_threshold_valid)
+    
+        
     mean_train_score = statistics.mean(list_train_score)
     std_train_score = statistics.pstdev(list_train_score)
             
@@ -285,8 +305,12 @@ def objective_with_prune(trial: Trial, fast_check=True, X=None,y=None,fn_params=
         'mean_FN_train':mean_FN_train   ,
         'std_FN_train':std_FN_train   ,
         
-       
-         
+
+        
+        'mean_train_opt_threshold':mean_train_opt_threshold   ,
+        'std_train_opt_threshold':std_train_opt_threshold   ,
+        
+        
         'mean_TP_train_opt':mean_TP_train_opt   ,
         'std_TP_train_opt':std_TP_train_opt   ,
         'mean_FP_train_opt':mean_FP_train_opt   ,
@@ -317,6 +341,9 @@ def objective_with_prune(trial: Trial, fast_check=True, X=None,y=None,fn_params=
         'mean_FN_valid':mean_FN_valid   ,
         'std_FN_valid':std_FN_valid   ,
         
+        'mean_valid_opt_threshold':mean_valid_opt_threshold   ,
+        'std_valid_opt_threshold':std_valid_opt_threshold   ,
+        
         
         'mean_TP_valid_opt':mean_TP_valid_opt   ,
         'std_TP_valid_opt':std_TP_valid_opt   ,
